@@ -19,10 +19,13 @@
 // Bound library includes
 #include <Qt3DLogic/qframeaction.h>
 
+QT_BEGIN_NAMESPACE
+
 namespace Qt3DLogic {
     class QFrameAction;
     class QLogicAspect;
 }
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -43,6 +46,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_Qt3DLogicTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_Qt3DLogicTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_Qt3DLogicModuleObject;
 
