@@ -37,6 +37,8 @@
 #include <QtGraphs/qitemmodelsurfacedataproxy.h>
 #include <QtGraphs/qseriestheme.h>
 #include <QtGraphs/qsurface3dseries.h>
+
+QT_BEGIN_NAMESPACE
 class Q3DBars;
 class Q3DInputHandler;
 class Q3DScatter;
@@ -66,6 +68,7 @@ class QValue3DAxis;
 class QValue3DAxisFormatter;
 class QValueAxis;
 class QXYSeries;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -218,6 +221,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtGraphsTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtGraphsTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtGraphsModuleObject;
 
