@@ -347,6 +347,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtNetworkTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtNetworkTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtNetworkModuleObject;
 
